@@ -1,8 +1,3 @@
-
-
-
-
-
 """
 These tests work on any integrations using BasicRest classes
 """
@@ -28,7 +23,6 @@ sys.path.append(os.getcwd())
 
 # Globals
 DATA_DIR = f'{os.getcwd()}/tests'
-# Config Variables
 
 
 def get_task_names():
@@ -162,7 +156,7 @@ class TestStandardRest:
         """
         This will test the payload schema json, params, data, files, etc. As utils passes it.
         """
-        schema = json.loads(open(f'{DATA_DIR}/{self.task}/schemas/payload.json').read())
+        schema = json.loads(open(f'{DATA_DIR}/{self.task}/schemas/kwargs.json').read())
         validate(
             instance=self.ctx.get_kwargs(),
             schema=schema
@@ -172,7 +166,18 @@ class TestStandardRest:
         """
         Verify session headers against schema
         """
-        schema = json.loads(open(f'{DATA_DIR}/{self.task}/schemas/headers.json').read())
+        # check if local header schema, this overrides global.
+        try:
+            schema = json.loads(open(f'{DATA_DIR}/{self.task}/schemas/headers.json').read())
+        except:
+            schema = False
+        if not schema:
+            # check if global schema
+            schema = json.loads(open(f'{DATA_DIR}/headers.json').read())
+            if not schema:
+                raise ValueError(
+                    'Must define the header schema globally or specifically in the task.'
+                )
         validate(
             instance=self.ctx.session.headers,
             schema=schema
@@ -198,11 +203,11 @@ class TestStandardRest:
         for record in resp:
             for k, v in record.items():
                 _type = schema.get(k, {}).get('type')
-                # Todo handle all of the types in output_verify.py and rewrite this POC.
-                if _type in [1, 6, 5, 9]:
+                if _type:
                     if not OUTPUT_MAP[_type](v):
-                        raise TypeError(f'Output Key: {k}, Type: {_type}\nValue: {v}')
+                        assert False, f'Output Key: {k}, Type: {_type}\nValue: {v}'
                 else:
                     missing.append(k)
-
+        if missing:
+            assert False, f'Manifest is missing outputs: {missing}'
         return True
